@@ -4,10 +4,10 @@ It can be used to bootstrap:
 - a new board support
 - a new external application
 - a new RIOT example application
+- a new RIOT driver
+- a new RIOT system module
 - a new test application
 - a new package for RIOT
 """
 
-__version__ = '0.3.2'
-
-from .generator import cli  # noqa
+__version__ = "0.4.1"
